library IEEE;
use IEEE.std_logic_1164.all;

entity debug_ckt is
    port (DEBUG_CLK_8M : in STD_LOGIC;
          SYS_CLK_15HZ : in STD_LOGIC;
          GSRT	       : in STD_LOGIC;
          EXT_CLK      : in STD_LOGIC;
          CLK_SEL      : in STD_LOGIC;
          CLK          : out STD_LOGIC);
end debug_ckt;

architecture debug_ckt_arch of debug_ckt is

component STARTUP 
	port (GSR: in std_logic);
end component;

component RDBK
        port (TRIG: in std_logic; 
	      DATA: out std_logic);
end component;

component IBUF
	port (I: in std_logic;
	      O: out std_logic);
end component;

component OBUF
	port (I: in std_logic;
	      O: out std_logic);
end component;

component MD0
	port (I: out std_logic);
end component;

component MD1
	port (O: in std_logic);
end component;


signal nGSRT: STD_LOGIC;
signal TRIG, intTRIG: STD_LOGIC;
signal DATA, intDATA: STD_LOGIC;
signal q_CLK_SEL: STD_LOGIC;
signal mux_out: STD_LOGIC;

begin

nGSRT<=not GSRT;

START_INST: STARTUP port map (GSR=>nGSRT);

READ_INST: RDBK port map (TRIG=>intTRIG, DATA=>intDATA);

TRIG_BUF: IBUF port map (I=>TRIG, O=>intTRIG);

DATA_BUF: OBUF port map (I=>intDATA, O=>DATA);

TRIG_PAD: MD0 port map (I=>TRIG);

DATA_PAD: MD1 port map (O=>DATA);

process(DEBUG_CLK_8M,q_CLK_SEL, EXT_CLK, SYS_CLK_15HZ)
begin
     if (q_CLK_SEL='1') then
       mux_out<=EXT_CLK;
     else
       mux_out<=SYS_CLK_15HZ;
     end if;
   if(rising_edge(DEBUG_CLK_8M)) then
	CLK <= mux_out;
	q_CLK_SEL <= CLK_SEL;
   end if;
end process;

end DEBUG_CKT_arch;
