library IEEE;
use IEEE.std_logic_1164.all;
--library UNISIM;
--use UNISIM.all;

entity stopwatch is
    port (    RESET : in STD_LOGIC;
	   STRTSTOP : in STD_LOGIC;
	  TENTHSOUT : out STD_LOGIC_VECTOR(9 downto 0);
	    ONESOUT : out STD_LOGIC_VECTOR(6 downto 0);
	    TENSOUT : out STD_LOGIC_VECTOR(6 downto 0);
	       GSRT : in STD_LOGIC;
	 CLK_SELECT : in STD_LOGIC;
            EXT_CLK : in STD_LOGIC;
       CLK_OUT_15HZ : out STD_LOGIC);
end stopwatch;

architecture inside of stopwatch is

component OSC4
    port (F8M : out STD_LOGIC;
          F15 : out STD_LOGIC);
end component;

component BUFG
    port (I : in STD_LOGIC;
	  O : out STD_LOGIC);
end component;

component statmach
    port (     CLK : in STD_LOGIC;
	     RESET : in STD_LOGIC;
	  STRTSTOP : in STD_LOGIC;
	     CLKEN : out STD_LOGIC;
	       RST : out STD_LOGIC);
end component;

----------------------------------------------------------
--Copy "Component Declaration" statement of TENTHS.VHI

----------------------------------------------------------

component cnt60
    port (    CE : in STD_LOGIC;
	     CLK : in STD_LOGIC;
	     CLR : in STD_LOGIC;
	  LSBSEC : out STD_LOGIC_VECTOR(3 downto 0);
	  MSBSEC : out STD_LOGIC_VECTOR(3 downto 0));
end component;

component hex2led
    port (HEX : in STD_LOGIC_VECTOR(3 downto 0);
	  LED : out STD_LOGIC_VECTOR(6 downto 0));
end component;

component debug_ckt
    port (DEBUG_CLK_8M : in STD_LOGIC;
          SYS_CLK_15HZ : in STD_LOGIC;
          GSRT	       : in STD_LOGIC;
          EXT_CLK      : in STD_LOGIC;
          CLK_SEL      : in STD_LOGIC;
          CLK          : out STD_LOGIC);
end component;

signal strtstopinv : STD_LOGIC;
signal oscout : STD_LOGIC;
signal clkint : STD_LOGIC;
signal clkenable : STD_LOGIC;
signal rstint : STD_LOGIC;
signal xcountout : STD_LOGIC_VECTOR(9 downto 0);
signal xtermcnt : STD_LOGIC;
signal cnt60enable : STD_LOGIC;
signal lsbcnt : STD_LOGIC_VECTOR(3 downto 0);
signal msbcnt : STD_LOGIC_VECTOR(3 downto 0);
signal clk_8m : STD_LOGIC;
signal clk_15hz : STD_LOGIC;

begin

OSCILLATOR:OSC4 port map(F8M=>clk_8m, F15=>clk_15hz);

DEBUG:DEBUG_CKT port map(DEBUG_CLK_8M=>clk_8m,
			 SYS_CLK_15HZ=>clk_15hz,
			 GSRT=>GSRT,
          		 EXT_CLK=>EXT_CLK,
          		 CLK_SEL=>CLK_SELECT,
			 CLK=>oscout);

CLOCKBUF:BUFG port map(I=>oscout,O=>clkint);

MACHINE:statmach port map(CLK=>clkint,
	                  RESET=>RESET,
	                  STRTSTOP=>strtstopinv,
	                  CLKEN=>clkenable,
	                  RST=>rstint);

--Place the Logiblox Component Instantiation for Tenths here
----------------------------------------------------
-- Component Instantiation 
----------------------------------------------------
XCOUNTER : tenths port map
(CLK_EN => clkenable,
 CLOCK => clkint,
 ASYNC_CTRL => rstint,
 Q_OUT => xcountout,
 TERM_CNT => xtermcnt);

sixty: cnt60 port map(CE=>cnt60enable,
	              CLK=>clkint,
	              CLR=>rstint,
	              LSBSEC=>lsbcnt,
	              MSBSEC=>msbcnt);

lsbled:hex2led port map(HEX=>lsbcnt,
			LED=>ONESOUT);

msbled:hex2led port map(HEX=>msbcnt,
			LED=>TENSOUT);
			
cnt60enable<=xtermcnt and clkenable;
TENTHSOUT<=not(xcountout);
strtstopinv<=not(STRTSTOP);
CLK_OUT_15HZ<=clk_15hz;

end inside;
